#define rini_init
/*
rini_init();

Arguments:
-None-

Return Value:
-None-

Description:
Must be called somewhere BEFORE any other RINI related function is called.

Notes:
-None-
*/


dllname = "IniLibGMDLL.dll";

global.INI_DLL_Open=external_define(dllname,"rini_open",dll_cdecl,ty_real,2,ty_string,ty_string);
global.INI_DLL_Close=external_define(dllname,"rini_close",dll_cdecl,ty_real,1,ty_real);
global.INI_DLL_Write=external_define(dllname,"rini_write",dll_cdecl,ty_real,1,ty_real);
global.INI_DLL_GetKeyVal=external_define(dllname,"rini_read_real",dll_cdecl,ty_real,4,ty_real,ty_string,ty_string,ty_string);
global.INI_DLL_GetKeyString=external_define(dllname,"rini_read_string",dll_cdecl,ty_string,4,ty_real,ty_string,ty_string,ty_string);
global.INI_DLL_SetKeyVal=external_define(dllname,"rini_write_real",dll_cdecl,ty_real,4,ty_real,ty_string,ty_string,ty_string);
global.INI_DLL_SetKeyString=external_define(dllname,"rini_write_string",dll_cdecl,ty_real,4,ty_real,ty_string,ty_string,ty_string);
global.INI_DLL_SectionExists=external_define(dllname,"rini_section_exists",dll_cdecl,ty_real,2,ty_real,ty_string);
global.INI_DLL_KeyExists=external_define(dllname,"rini_key_exists",dll_cdecl,ty_real,3,ty_real,ty_string,ty_string);
global.INI_DLL_KeyRename=external_define(dllname,"rini_key_rename",dll_cdecl,ty_real,4,ty_real,ty_string,ty_string,ty_string);
global.INI_DLL_SectionRename=external_define(dllname,"rini_section_rename",dll_cdecl,ty_real,3,ty_real,ty_string,ty_string);
global.INI_DLL_SectionDelete=external_define(dllname,"rini_section_delete",dll_cdecl,ty_real,2,ty_real,ty_string);
global.INI_DLL_KeyDelete=external_define(dllname,"rini_key_delete",dll_cdecl,ty_real,3,ty_real,ty_string,ty_string);
global.INI_DLL_SectionFirst=external_define(dllname,"rini_section_find_first",dll_cdecl,ty_string,1,ty_real);
global.INI_DLL_SectionNext=external_define(dllname,"rini_section_find_next",dll_cdecl,ty_string,1,ty_real);


global.INI_DLL_KeyFirst=external_define(dllname,"rini_key_find_first",dll_cdecl,ty_string,2,ty_real,ty_string);
global.INI_DLL_KeyNext=external_define(dllname,"rini_key_find_next",dll_cdecl,ty_string,2,ty_real,ty_string);


#define rini_open
/*
rini_init(filename);

Arguments:
[0]filename:String = The name of the file to open (eg. config.ini)

Return Value:
returns a HANDLE which needs to be used on all other functions to
operate on the ini file that was opened

Description:
Opens an ini file for operating on. The ini file is loaded into
the memory for fast operations. The data isn't written to the hard drive (file)
again until it is CLOSED with rini_close() or rini_write();

Notes:
-None-
*/

return external_call(global.INI_DLL_Open,argument0,argument1);

#define rini_close
/*
rini_close(iniHandle);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())

Return Value:
-None-

Description:
Writes the ini file back on the hard drive (essentially "saves the changes")
and frees file from memory. Obviously you cannot continue operations on this ini file
after it's closed

Notes:
-None-
*/

return external_call(global.INI_DLL_Close,argument0);

#define rini_write
/*
rini_write(iniHandle);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())

Return Value:
-None-

Description:
Writes the ini file to the hard drive. rini_close() will automatically call this

Notes:
-None-
*/

return external_call(global.INI_DLL_Write,argument0);

#define rini_read_real
/*
rini_read_real(iniHandle, Section, Key, DefaultVal);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The name of the Section
[2]Key:String = The name of the Key
[3]DefaultVal:Real = Default value to be returned if the entry doesn't exist
Return Value:
returns the value read from the ini file.

Description:
Reads a Real (number) from the ini file.

Notes:
-None-
*/

return external_call(global.INI_DLL_GetKeyVal,argument0,argument1,argument2,string(argument3));

#define rini_read_string
/*
rini_read_string(iniHandle, Section, Key, DefaultVal);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The name of the Section
[2]Key:String = The name of the Key
[3]DefaultVal:String = Default value to be returned if the entry doesn't exist
Return Value:
returns the value read from the ini file.

Description:
Reads a String from the ini file.

Notes:
-None-
*/


return external_call(global.INI_DLL_GetKeyString,argument0,argument1,argument2,argument3);

#define rini_write_real
/*
rini_write_real(iniHandle, Section, Key, Val);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The name of the Section
[2]Key:String = The name of the Key
[3]Val:Real = Value to write
Return Value:
returns 0 if there was a problem.. 1 on success

Description:
Writes a value to the ini file, replacing anything that already exists
or creating a new entry otherwise

Notes:
-None-
*/

return external_call(global.INI_DLL_SetKeyVal,argument0,argument1,argument2,string(argument3));

#define rini_write_string
/*
rini_write_string(iniHandle, Section, Key, Val);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The name of the Section
[2]Key:String = The name of the Key
[3]Val:String = String to write
Return Value:
returns 0 if there was a problem.. 1 on success

Description:
Writes a string to the ini file, replacing anything that already exists
or creating a new entry otherwise

Notes:
-None-
*/

return external_call(global.INI_DLL_SetKeyString,argument0,argument1,argument2,argument3);

#define rini_section_exists
/*
rini_section_exists(iniHandle, Section);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The name of the Section to check

Return Value:
returns true if it exists, false if it doesnt exist

Description:
Checks if a Section exists in the ini file
Notes:
-None-
*/

return external_call(global.INI_DLL_SectionExists,argument0,argument1);

#define rini_key_exists
/*
rini_key_exists(iniHandle, Section, Key);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The name of the Section to check
[2]Key:String = The name of the Key

Return Value:
returns true if it exists, false if it doesnt exist

Description:
Checks if a Key exists in the ini file
Notes:
-None-
*/

return external_call(global.INI_DLL_KeyExists,argument0,argument1,argument2);

#define rini_key_rename
/*
rini_key_rename(iniHandle, Section, Key, newName);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The name of the Section
[2]Key:String = The name of the Key
[3]newName:String = The new name to change the key to


Return Value:
returns 0 on failure, 1 on sucess

Description:
Renames a key in the ini file.
Notes:
-None-
*/

return external_call(global.INI_DLL_KeyRename,argument0,argument1,argument2,argument3);

#define rini_section_rename
/*
rini_section_rename(iniHandle, Section, newName);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The name of the Section 
[2]newName:String = The new name to change the section name to


Return Value:
returns 0 on failure, 1 on sucess

Description:
Renames a section in the ini file
Notes:
-None-
*/

return external_call(global.INI_DLL_SectionRename,argument0,argument1,argument2);

#define rini_key_delete
/*
rini_key_delete(iniHandle, Section, Key);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The name of the Section
[2]Key:String= The Key to delete


Return Value:
returns 0 on failure, 1 on sucess

Description:
Deletes a key
Notes:
-None-
*/

return external_call(global.INI_DLL_KeyDelete,argument0,argument1,argument2);

#define rini_section_delete
/*
rini_section_delete(iniHandle, Section);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The name of the Section to Delete



Return Value:
returns 0 on failure, 1 on sucess

Description:
Deletes an entire section, along with all of the keys inside of it.
Notes:
-None-
*/

return external_call(global.INI_DLL_SectionDelete,argument0,argument1);

#define rini_section_find_first
/*
rini_section_find_first(iniHandle);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())

Return Value:
returns the name of the first section in the ini file, or "" if nothing was found

Description:
Finds the first section in an ini file. Good for iterating/searching through
all of the sections in a file. This needs to be called before rini_section_find_next();
Notes:
-None-
*/

return external_call(global.INI_DLL_SectionFirst,argument0);

#define rini_section_find_next
/*
rini_section_find_next(iniHandle);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())

Return Value:
returns the name of the next section in the ini file, or "" if nothing was found
(a.k.a "End of File")

Description:
Finds the next section in an ini file. Good for iterating/searching through
all of the sections in a file. rini_section_find_next() needs to be called before this.
Notes:
-None-
*/

return external_call(global.INI_DLL_SectionNext,argument0);

#define rini_key_find_first
/*
rini_section_find_next(iniHandle, Section);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The section to search in
Return Value:
Returns the name of the first key in a section. returns "" if nothing was found.

Description:
Finds the first Key in the specified section, this is good for iterating/searching through
all the keys in a specific section. This function needs to be called before rini_key_find_next()
Notes:
-None-
*/

return external_call(global.INI_DLL_KeyFirst,argument0,argument1);

#define rini_key_find_next
/*
rini_section_find_next(iniHandle, Section);

Arguments:
[0]iniHandle:Real = The handle to the ini file (from rini_open())
[1]Section:String = The section to search in
Return Value:
Returns the name of the next key in a section. returns "" if nothing was found, 
or there are no more keys to find (a.k.a. "End of file"/"End of List")

Description:
Finds the next Key in the specified section, this is good for iterating/searching through
all the keys in a specific section. rini_key_find_first() needs to be called BEFORE this function with the same Section name.
Notes:
-None-
*/



return external_call(global.INI_DLL_KeyNext,argument0,argument1);

